@@ -28,7 +28,7 @@
 
 #include <Core/SpawningKit/Spawner.h>
 #include <Constants.h>
-#include <Logging.h>
+#include <LoggingKit/LoggingKit.h>
 #include <LveLoggingDecorator.h>
 #include <limits.h>  // for PTHREAD_STACK_MIN
 #include <pthread.h>
@@ -127,7 +127,7 @@ private:
 		if (shouldLoadShellEnvvars(options, preparation)) {
 			command.push_back(preparation.userSwitching.shell);
 			command.push_back(preparation.userSwitching.shell);
-			if (Passenger::getLogLevel() >= LVL_DEBUG3) {
+			if (LoggingKit::getLevel() >= LoggingKit::DEBUG3) {
 				command.push_back("-lxc");
 			} else {
 				command.push_back("-lc");
@@ -242,7 +242,9 @@ public:
 					errorPipe.first,
 					pid,
 					// The cast works around a compilation problem in Clang.
-					(const char *) "stderr");
+					(const char *) "stderr",
+					options.getAppGroupName(),
+					options.appLogFile);
 			details.stderrCapturer->start();
 			details.pid = pid;
 			details.adminSocket = adminSocket.second;
